#!/bin/bash
# ATMEL Wireless Card Setup for linux
# Copyright 2001 (c) ATMEL Hellas

if [ $# -gt 0 ]; then
	CONFIG_FILE=$1
else
	echo "You must provide the output file as an argument to the script"
	exit
fi

function CheckKernelVersion
{
    if [ -d $1 ]; then
        if [ -f $1/Makefile ]; then
            for TAG in VERSION PATCHLEVEL SUBLEVEL EXTRAVERSION ; do
                eval `sed -ne "/^$TAG/s/[ 	]//gp" $1/Makefile`
            done
            FV="$VERSION.$PATCHLEVEL.$SUBLEVEL$EXTRAVERSION"
            if [ "$LV" = "$FV" ]; then
                if [ "$PATH_FOUND" = "n" ]; then
                    PATH_FOUND=y
                    SRCPATH=$1
                fi
            fi
        fi
    fi
}

PATH_FOUND=n
MPA=/usr/src
CONFIGP="/etc/pcmcia"
USB_CONFIG="/etc/hotplug"
LV=$(uname -r)

PCMCIADES="/lib/modules/$LV/pcmcia"
PCMCIA_SRC="null"
MODPROBE_PATH=$(which modprobe)

if [ $KERNEL_SRC ]; then 
	echo $KERNEL_SRC "(defined)"
	SRCPATH=$KERNEL_SRC
else
	if [ -L /lib/modules/$LV/build ]&&[ -f /lib/modules/$LV/build/Makefile ]; then
		SRCPATH=/lib/modules/$LV/build
	else
		for f in $MPA/*; do CheckKernelVersion $f ; done
	fi

	echo "Kernel Version Running $LV"

	if [ "$SRCPATH" = "null" ]; then
		echo -e "Kernel Source Directory Not Found. Please give path : \c"
		read SRCPATH
		if [ ! -d $SRCPATH ]; then
			echo "Invalid Path"
			rm -f config.mk
		fi
	else
		echo Found Kernel Source Directory "($SRCPATH)"
	fi

	echo KERNEL_SRC = $SRCPATH >> $CONFIG_FILE
fi

if [ $# -gt 0 ]; then
    PCMCIA_IN_KERNEL=$(grep -c CONFIG_PCMCIA= $SRCPATH/.config)

    if [ $PCMCIA_IN_KERNEL -eq 1 ] ; then
	PCMCIA_SRC=$SRCPATH
    else
	for f in $SRCPATH/pcmcia*; do
	    if [ -L $f ]; then
		if [ -d $f/include ]; then
		    PCMCIA_SRC=$f
		    break
	    fi
	    fi

	    if [ -d $f ]; then
	    if [ -d $f/include ]; then
		    PCMCIA_SRC=$f
		    break
	    fi
	    fi
	done
	if [ "$PCMCIA_SRC" = "null" ]; then
	    echo "Pcmcia card services source needed but not found"
	    echo "Please give desired path.If you have the kernel"
	    echo "support for the PCMCIA card services you still"
	    echo "have to install the corresponding version of "
	    echo "the card services"
	    read PCMCIA_SRC
	fi

	if [ ! -d $PCMCIA_SRC/include ] && [ "$PCMCIA_SRC" != "" ]; then
	    echo "Invalid directory. Check pcmcia source path and retry"
	    exit -1;
	fi
    fi
fi

if [ -f $PCMCIA_DES ];then
	echo PCMCIA_CONFIG = $CONFIGP >> $CONFIG_FILE
	echo PCMCIA_SRC = $PCMCIA_SRC >> $CONFIG_FILE
fi

if [ -f $PCMCIA_DES ];then
	echo PCMCIA_DES = $PCMCIADES >> $CONFIG_FILE
fi
echo >> $CONFIG_FILE
echo >> $CONFIG_FILE
